==> apache-drill-1.17.0-src.zip: apache-drill-1.17.0-src/exec/java-exec/src/main/java/org/apache/drill/exec/store/sys/CaseInsensitivePersistentStore.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.store.sys;

import java.util.Iterator;
import java.util.Map;

/**
 * Wrapper around {@link PersistentStore} to ensure all passed keys are converted to lower case and stored this way.
 * This will ensure case-insensitivity during insert, update, deletion or search.
 */
public class CaseInsensitivePersistentStore<V> implements PersistentStore<V> {

  private final PersistentStore<V> underlyingStore;

  public CaseInsensitivePersistentStore(PersistentStore<V> underlyingStore) {
    this.underlyingStore = underlyingStore;
  }

  @Override
  public boolean contains(String key) {
    return underlyingStore.contains(key.toLowerCase());
  }

  @Override
  public V get(String key) {
    return underlyingStore.get(key.toLowerCase());
  }

  @Override
  public void put(String key, V value) {
    underlyingStore.put(key.toLowerCase(), value);
  }

  @Override
  public Iterator<Map.Entry<String, V>> getAll() {
    return underlyingStore.getAll();
  }

  @Override
  public PersistentStoreMode getMode() {
    return underlyingStore.getMode();
  }

  @Override
  public void delete(String key) {
    underlyingStore.delete(key.toLowerCase());
  }

  @Override
  public boolean putIfAbsent(String key, V value) {
    return underlyingStore.putIfAbsent(key.toLowerCase(), value);
  }

  @Override
  public Iterator<Map.Entry<String, V>> getRange(int skip, int take) {
    return underlyingStore.getRange(skip, take);
  }

  @Override
  public void close() throws Exception {
    underlyingStore.close();
  }
}

==> apache-drill-1.22.0-src.zip: apache-drill-1.22.0-src/exec/java-exec/src/main/java/org/apache/drill/exec/store/sys/CaseInsensitivePersistentStore.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.store.sys;

import java.util.Iterator;
import java.util.Map;

/**
 * Wrapper around {@link PersistentStore} to ensure all passed keys are
 * converted to lower case and stored this way. This will ensure
 * case-insensitivity during insert, update, deletion or search.
 */
public class CaseInsensitivePersistentStore<V> implements PersistentStore<V> {

  private final PersistentStore<V> underlyingStore;

  public CaseInsensitivePersistentStore(PersistentStore<V> underlyingStore) {
    this.underlyingStore = underlyingStore;
  }

  @Override
  public boolean contains(String key) {
    return underlyingStore.contains(key.toLowerCase());
  }

  @Override
  public V get(String key) {
    return underlyingStore.get(key.toLowerCase());
  }

  @Override
  public void put(String key, V value) {
    underlyingStore.put(key.toLowerCase(), value);
  }

  @Override
  public Iterator<Map.Entry<String, V>> getAll() {
    return underlyingStore.getAll();
  }

  @Override
  public PersistentStoreMode getMode() {
    return underlyingStore.getMode();
  }

  @Override
  public void delete(String key) {
    underlyingStore.delete(key.toLowerCase());
  }

  @Override
  public boolean putIfAbsent(String key, V value) {
    return underlyingStore.putIfAbsent(key.toLowerCase(), value);
  }

  @Override
  public Iterator<Map.Entry<String, V>> getRange(int skip, int take) {
    return underlyingStore.getRange(skip, take);
  }

  @Override
  public void close() throws Exception {
    underlyingStore.close();
  }
}
